@@ -1,7 +1,7 @@
 /*
  * dbus-client.c -- shared DBus client routines for pommed clients
  *
- * Copyright (C) 2006-2007 Julien BLACHE <jb@jblache.org>
+ * Copyright (C) 2006-2007, 2009 Julien BLACHE <jb@jblache.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -238,6 +238,57 @@ mbp_call_audio_getmute(DBusPendingCallNotifyFunction cb, void *userdata)
   return 0;
 }
 
+int
+mbp_call_video_getvtstate(int vtnum, DBusPendingCallNotifyFunction cb, void *userdata)
+{
+  DBusMessage *msg;
+  DBusPendingCall *pending;
+
+  int ret;
+
+  msg = dbus_message_new_method_call("org.pommed", "/org/pommed/video",
+				     "org.pommed.video", "getVTState");
+
+  if (msg == NULL)
+    {
+      printf("Failed to create method call message\n");
+
+      return -1;
+    }
+
+  ret = dbus_message_append_args(msg,
+				 DBUS_TYPE_UINT32, &vtnum,
+				 DBUS_TYPE_INVALID);
+  if (ret == FALSE)
+    {
+      printf("Failed to add arguments\n");
+
+      dbus_message_unref(msg);
+
+      return -1;
+    }
+
+  ret = dbus_connection_send_with_reply(conn, msg, &pending, 250);
+  if (ret == FALSE)
+    {
+      printf("Could not send method call\n");
+
+      dbus_message_unref(msg);
+
+      return -1;
+    }
+
+  dbus_connection_flush(conn);
+
+  dbus_message_unref(msg);
+
+  dbus_pending_call_block(pending);
+
+  cb(pending, userdata);
+
+  return 0;
+}
+
 
 /* Error checking, mainly for replies to method calls */
 
