@@ -1,7 +1,7 @@
 /*
  * video-client.c -- shared video switch routines for pommed clients
  *
- * Copyright (C) 2007 Julien BLACHE <jb@jblache.org>
+ * Copyright (C) 2007, 2009 Julien BLACHE <jb@jblache.org>
  *
  * Some code below taken from GDM where noted.
  *
@@ -47,7 +47,7 @@ static char *vsw_user = NULL;
  * Get the VT number X is running on
  * (code taken from GDM, daemon/getvt.c, GPLv2+)
  */
-static int
+int
 mbp_get_x_vtnum(Display *dpy)
 {
   Atom prop;
@@ -106,73 +106,18 @@ mbp_get_x_vtnum(Display *dpy)
   return num;
 }
 
-/*
- * Determine whether the frontend is running on the active X session
- * aka the X session associated to the active VT.
- *
- * On error, return 1 by default, 0 when the error could mean we're not safe.
- */
-static int
-mbp_frontend_is_active(Display *dpy)
-{
-  int vt;
-  int fd;
-  char buf[16];
-  struct vt_stat vtstat;
-
-  int ret;
-
-  vt = mbp_get_x_vtnum(dpy);
-
-  ret = snprintf(buf, sizeof(buf), "/dev/tty%d", vt);
-  if ((ret < 0) || (ret >= sizeof(buf)))
-    return 1;
-
-  /* Try to open the VT our X session is running on */
-  fd = open(buf, O_RDWR);
-
-  if ((fd < 0) && (errno == EACCES))
-    fd = open(buf, O_RDONLY);
-
-  if ((fd < 0) && (errno == EACCES))
-    fd = open(buf, O_WRONLY);
-
-  /* Can't open the VT, this shouldn't happen; maybe X is remote? */
-  if (fd < 0)
-    return 0;
-
-  /* Our VT isn't a tty, WTF?! */
-  if (!isatty(fd))
-    {
-      close(fd);
-      return 0;
-    }
-
-  /* Get VT state, includes active VT */
-  ret = ioctl(fd, VT_GETSTATE, &vtstat);
-  close(fd);
-
-  if (ret < 0)
-    return 1;
-
-  return (vt == vtstat.v_active);
-}
-
 
 /*
  * NOTE: you MUST install a SIGCHLD handler if you use this function
  */
 void
-mbp_video_switch(Display *dpy)
+mbp_video_switch(void)
 {
   struct passwd *pw;
   char *vsw = NULL;
 
   int ret;
 
-  if (!mbp_frontend_is_active(dpy))
-    return;
-
   if (vsw_user == NULL)
     {
       pw = getpwuid(getuid());
