@@ -9,8 +9,11 @@
 #define VIDEO_SWITCH_USER        "/.videoswitch"
 
 
+int
+mbp_get_x_vtnum(Display *dpy);
+
 void
-mbp_video_switch(Display *dpy);
+mbp_video_switch(void);
 
 
 #endif /* !__MBP_VIDEO_CLIENT_H__ */
