@@ -662,6 +662,35 @@ evdev_is_wellspring4a(unsigned short *id)
   return 0;
 }
 
+/* MacBookPro8,1 (13" Early 2011)
+ * MacBookPro8,2 (15" Early 2011)
+ * MacBookPro8,3 (17" Early 2011)
+ */
+static int
+evdev_is_wellspring5(unsigned short *id)
+{
+  unsigned short product = id[ID_PRODUCT];
+
+  if (id[ID_BUS] != BUS_USB)
+    return 0;
+
+  if (id[ID_VENDOR] != USB_VENDOR_ID_APPLE)
+    return 0;
+
+  if ((product == USB_PRODUCT_ID_WELLSPRING5_ANSI)
+      || (product == USB_PRODUCT_ID_WELLSPRING5_ISO)
+      || (product == USB_PRODUCT_ID_WELLSPRING5_JIS))
+    {
+      logdebug(" -> WellSpring V USB assembly\n");
+
+      kbd_set_fnmode();
+
+      return 1;
+    }
+
+  return 0;
+}
+
 /* Any internal keyboard */
 static int
 evdev_is_internal(unsigned short *id)
@@ -673,7 +702,8 @@ evdev_is_internal(unsigned short *id)
 	  || evdev_is_wellspring2(id)
 	  || evdev_is_wellspring3(id)
 	  || evdev_is_wellspring4(id)
-	  || evdev_is_wellspring4a(id));
+	  || evdev_is_wellspring4a(id)
+	  || evdev_is_wellspring5(id));
 }
 
 
