@@ -304,6 +304,17 @@ struct machine_ops mb_mops[] = {
     /* .evdev_identify = evdev_is_wellspring3, */
   },
 
+  {  /* MacBookPro8,1 (13", Early 2011)
+      * MacBookPro8,2 (15", Early 2011)
+      * MacBookPro8,3 (17", Early 2011)
+      */
+    .type = MACHINE_MACBOOKPRO_8,
+    .lcd_backlight_probe = mbp_sysfs_backlight_probe,
+    .lcd_backlight_step = sysfs_backlight_step,
+    .lcd_backlight_toggle = sysfs_backlight_toggle,
+    /* .evdev_identify = evdev_is_wellspring5, */
+  },
+
   /* MacBook machines */
 
   {  /* MacBook1,1 (Core Duo) */
@@ -737,6 +748,14 @@ check_machine_dmi(void)
   /* Core2 Duo MacBook Pro 13" (April 2010) */
   else if (strcmp(buf, "MacBookPro7,1") == 0)
     ret = MACHINE_MACBOOKPRO_7;
+  /* MacBook Pro 13" (Early 2011)
+   * MacBook Pro 15" (Early 2011)
+   * MacBook Pro 17" (Early 2011)
+   */
+  else if ((strcmp(buf, "MacBookPro8,1") == 0)
+	   || (strcmp(buf, "MacBookPro8,2") == 0)
+	   || (strcmp(buf, "MacBookPro8,3") == 0))
+    ret = MACHINE_MACBOOKPRO_8;
   /* Core Duo MacBook (May 2006) */
   else if (strcmp(buf, "MacBook1,1") == 0)
     ret = MACHINE_MACBOOK_1;
