@@ -43,9 +43,12 @@ enum {
   SYSFS_DRIVER_RIVA,
 #else
   SYSFS_DRIVER_MBP,
-  SYSFS_DRIVER_NOUVEAU,
+  SYSFS_DRIVER_APPLE,
   SYSFS_DRIVER_NVIDIA,
+  SYSFS_DRIVER_NOUVEAU,
+  SYSFS_DRIVER_ACPI,
 #endif
+  SYSFS_DRIVER_MAX
 };
 
 
@@ -63,8 +66,10 @@ static char *actual_brightness[] =
     "/sys/class/backlight/rivabl0/actual_brightness",
 #else
     "/sys/class/backlight/mbp_backlight/actual_brightness",
+    "/sys/class/backlight/apple_backlight/actual_brightness",
     "/sys/class/backlight/nvidia_backlight/actual_brightness",
     "/sys/class/backlight/nv_backlight/actual_brightness",
+    "/sys/class/backlight/acpi_video0/actual_brightness",
 #endif
   };
 
@@ -79,8 +84,10 @@ static char *brightness[] =
     "/sys/class/backlight/rivabl0/brightness",
 #else
     "/sys/class/backlight/mbp_backlight/brightness",
+    "/sys/class/backlight/apple_backlight/brightness",
     "/sys/class/backlight/nvidia_backlight/brightness",
     "/sys/class/backlight/nv_backlight/brightness",
+    "/sys/class/backlight/acpi_video0/brightness",
 #endif
   };
 
@@ -95,8 +102,10 @@ static char *max_brightness[] =
     "/sys/class/backlight/rivabl0/max_brightness",
 #else
     "/sys/class/backlight/mbp_backlight/max_brightness",
+    "/sys/class/backlight/apple_backlight/max_brightness",
     "/sys/class/backlight/nvidia_backlight/max_brightness",
     "/sys/class/backlight/nv_backlight/max_brightness",
+    "/sys/class/backlight/acpi_video0/max_brightness",
 #endif
   };
 
@@ -403,22 +412,15 @@ nvidia_sysfs_backlight_probe(void)
 int
 mbp_sysfs_backlight_probe(void)
 {
+  int drv;
   int ret;
 
-  ret = sysfs_backlight_probe(SYSFS_DRIVER_MBP);
-
-  if (ret == 0)
-    return 0;
-
-  ret = sysfs_backlight_probe(SYSFS_DRIVER_NOUVEAU);
-
-  if (ret == 0)
-    return 0;
-
-  ret = sysfs_backlight_probe(SYSFS_DRIVER_NVIDIA);
-
-  if (ret == 0)
-    return 0;
+  for (drv = SYSFS_DRIVER_NONE + 1; drv < SYSFS_DRIVER_MAX; drv++)
+    {
+      ret = sysfs_backlight_probe(drv);
+      if (ret == 0)
+	return 0;
+    }
 
   /* Probe failed, wire up native driver instead */
   switch (mops->type)
